StateManagementOption enum

Defines the available state management options for the Flutter project.

Inheritance
Available extensions

Values

none → const StateManagementOption

No specific state management solution.

provider → const StateManagementOption

Uses the provider package.

riverpod → const StateManagementOption

Uses the flutter_riverpod package.

bloc → const StateManagementOption

Uses the flutter_bloc package.

getx → const StateManagementOption

Uses the get package (GetX).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StateManagementOption>
A constant List of the values in this enum, in order of their declaration.