logDebug function
Logs a debug message to the console in magenta.
Implementation
void logDebug(String message) => print(_magenta('[DEBUG] $message'));
Logs a debug message to the console in magenta.
void logDebug(String message) => print(_magenta('[DEBUG] $message'));