logInfo function
Logs an informational message to the console in blue.
Implementation
void logInfo(String message) => print(_blue('[INFO] $message'));
Logs an informational message to the console in blue.
void logInfo(String message) => print(_blue('[INFO] $message'));