logWarning function
Logs a warning message to the console in yellow.
Implementation
void logWarning(String message) => print(_yellow('[!] $message'));
Logs a warning message to the console in yellow.
void logWarning(String message) => print(_yellow('[!] $message'));