templates library

Classes

StateManagementTemplates
A collection of static string templates specifically for state management related files, used by the Scaffolder to generate boilerplate code.
Templates
A collection of static string templates used for generating Flutter project files.