config library
Classes
- Config
- Represents the complete configuration for a new Flutter project.
Enums
- RoutingOption
- Defines the available routing options for the Flutter project.
- StateManagementOption
- Defines the available state management options for the Flutter project.