logger library
Functions
-
logDebug(
String message) → void - Logs a debug message to the console in magenta.
-
logError(
String message) → void - Logs an error message to the console in red.
-
logInfo(
String message) → void - Logs an informational message to the console in blue.
-
logSuccess(
String message) → void - Logs a success message to the console in green.
-
logWarning(
String message) → void - Logs a warning message to the console in yellow.