StateManagementTemplates class
A collection of static string templates specifically for state management
related files, used by the Scaffolder to generate boilerplate code.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- blocHomePageContent ↔ String
-
Template for the
home_page.dartfile when using BLoC state management.getter/setter pair - counterProviderContent ↔ String
-
Template for the
lib/providers/counter_provider.dartfile when using Provider.getter/setter pair - cubitTemplate ↔ String
-
Template for the
lib/cubits/counter_cubit.dartfile when using BLoC.getter/setter pair - getxControllerContent ↔ String
-
Template for the
lib/controllers/counter_controller.dartfile when using GetX.getter/setter pair - getxHomePageContent ↔ String
-
Template for the
home_page.dartfile when using GetX state management.getter/setter pair - proviiderHomePageContent ↔ String
-
Template for the
home_page.dartfile when using Provider state management.getter/setter pair - riverpodHomePageContent ↔ String
-
Template for the
home_page.dartfile when using Riverpod state management.getter/setter pair