Templates class
A collection of static string templates used for generating Flutter project files.
These templates are used by the Scaffolder to create the initial
structure and content of a new Flutter application based on user choices.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- appThemeContent ↔ String
-
Template for the
lib/constants/theme.dartfile when using FlexColorScheme.getter/setter pair - assetsContent ↔ String
-
Template for the
lib/constants/assets.dartfile.getter/setter pair - colorsContent ↔ String
-
Template for the
lib/constants/colors.dartfile.getter/setter pair - dotEnvContent ↔ String
-
Template for the
.envfile content.getter/setter pair - goRouterContent ↔ String
-
Template for the
lib/router/router.dartfile when using GoRouter.getter/setter pair - homePageContent ↔ String
-
Template for the default
lib/home_page.dartfile.getter/setter pair - localStorageServiceContent ↔ String
-
Template for the
lib/services/local_storage_service.dartfile.getter/setter pair - mainTemplate ↔ String
-
Template for the main
lib/main.dartfile.getter/setter pair - materialAppContent ↔ String
-
Template for the
MaterialAppwidget content.getter/setter pair - routeNames ↔ String
-
Template for the
lib/router/routes.dartfile.getter/setter pair - sizeUtilsContent ↔ String
-
Template for the
lib/utils/size_utils.dartfile.getter/setter pair